OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "ຟາຍຖຶກອັບໂຫລດສຳເລັດ",
    "No file was uploaded" : "ບໍ່ມີການອັບໂຫລດຟາຍ",
    "Translate" : "ແປ",
    "Copy link" : "ສຳເນົາລິງ",
    "Offline" : "ອັອບລາຍ",
    "Saving …" : "ກຳລັງບັນທຶກ",
    "Link" : "ລິງ",
    "Cancel" : "ຍົກເລີກ",
    "Replace" : "ປ່ຽນແທນ",
    "Upload" : "ອັບໂຫຼດ",
    "Edit" : "ແກ້ໄຂ",
    "Details" : "ລາຍລະອຽດ",
    "Choose" : "ເລືອກ"
},
"nplurals=1; plural=0;");
